@@ -1,7 +1,7 @@
 use Renard::Curie::Setup;
 package Renard::Curie::Component::Role::FromBuilder;
 # ABSTRACT: Role that loads a Glade UI file into a Gtk3::Builder
-$Renard::Curie::Component::Role::FromBuilder::VERSION = '0.001';
+$Renard::Curie::Component::Role::FromBuilder::VERSION = '0.002';
 use Moo::Role;
 use Renard::Curie::Types qw(InstanceOf);
 
@@ -12,11 +12,11 @@ has builder => (
 	isa => InstanceOf['Gtk3::Builder'],
 );
 
-method _build_builder :ReturnType(InstanceOf['Gtk3::Builder']) {
+method _build_builder() :ReturnType(InstanceOf['Gtk3::Builder']) {
 	return Gtk3::Builder->new;
 }
 
-before BUILD => method {
+before BUILD => method(@) {
 	$self->builder->add_from_file( $self->ui_file );
 	$self->builder->connect_signals;
 };
@@ -36,7 +36,7 @@ Renard::Curie::Component::Role::FromBuilder - Role that loads a Glade UI file in
 
 =head1 VERSION
 
-version 0.001
+version 0.002
 
 =head1 DESCRIPTION
 
