@@ -1,17 +1,17 @@
 use Renard::Curie::Setup;
 package Renard::Curie::Model::Document::PDF;
 # ABSTRACT: document that represents a PDF file
-$Renard::Curie::Model::Document::PDF::VERSION = '0.001';
+$Renard::Curie::Model::Document::PDF::VERSION = '0.002';
 use Moo;
 use Renard::Curie::Data::PDF;
 use Renard::Curie::Model::Page::RenderedFromPNG;
 use Renard::Curie::Model::Outline;
-use Renard::Curie::Types qw(PageNumber);
+use Renard::Curie::Types qw(PageNumber ZoomLevel);
 use Function::Parameters;
 
 extends qw(Renard::Curie::Model::Document);
 
-method _build_last_page_number :ReturnType(PageNumber) {
+method _build_last_page_number() :ReturnType(PageNumber) {
 	my $info = Renard::Curie::Data::PDF::get_mutool_page_info_xml(
 		$self->filename
 	);
@@ -19,20 +19,19 @@ method _build_last_page_number :ReturnType(PageNumber) {
 	return scalar @{ $info->{page} };
 }
 
-# TODO : need to implement zoom_level option
-method get_rendered_page( (PageNumber) :$page_number ) {
+method get_rendered_page( (PageNumber) :$page_number, (ZoomLevel) :$zoom_level = 1.0 ) {
 	my $png_data = Renard::Curie::Data::PDF::get_mutool_pdf_page_as_png(
-		$self->filename, $page_number,
+		$self->filename, $page_number, $zoom_level
 	);
 
 	return Renard::Curie::Model::Page::RenderedFromPNG->new(
 		page_number => $page_number,
 		png_data => $png_data,
-		zoom_level => 1,
+		zoom_level => $zoom_level,
 	);
 }
 
-method _build_outline {
+method _build_outline() {
 	my $outline_data = Renard::Curie::Data::PDF::get_mutool_outline_simple(
 		$self->filename
 	);
@@ -62,7 +61,7 @@ Renard::Curie::Model::Document::PDF - document that represents a PDF file
 
 =head1 VERSION
 
-version 0.001
+version 0.002
 
 =head1 EXTENDS
 
